# LinkPostModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**url** | **str** | Address can be specified without protocol, but necessarily with the domain. | 
**title** | **str, none_type** | Link name. | [optional] 
**description** | **str, none_type** | Link description. | [optional] 
**type** | [**LinkType**](LinkType.md) |  | [optional] 
**has_info** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


